# Practicing with *args
import pandas as pd
import timeit

from utils.area_between import area_between
from utils.crossover import crossover
from indicators.sma import sma


import itertools
import numpy as np
